.silk-empty__list {
  text-align: left;
  display: inline-block;
  margin: 0 0 1.5rem;
  font-size: 13px;
  color: var(--silk-text-secondary);

  li {
    margin-bottom: 4px;
  }

  code {
    background: var(--silk-filter-bg);
    border: 1px solid var(--silk-border);
    border-radius: 3px;
    padding: 1px 4px;
    font-size: 12px;
  }
}

.pyprofile {
  overflow: auto;
  max-height: 650px;
}
