.cell {
  display: inline-block;
  background-color: transparent;
  padding: 10px;
  margin-left: 10px;
  margin-top: 10px;
  border-radius: var(--silk-card-radius, 8px);
  box-shadow: var(--silk-card-shadow);
  transition: background-color 0.15s ease, color 0.15s ease;
}
.cell div {
  margin: 2px;
}
.cell .timestamp-div {
  margin-bottom: 15px;
  font-size: 13px;
}
.cell .meta {
  font-size: 12px;
  color: var(--silk-perf-bad);
}
.cell .meta .unit {
  font-size: 9px;
  font-weight: lighter !important;
}
.cell .method-div {
  font-weight: bold;
  font-size: 20px;
}
.cell .path-div {
  font-size: 18px;
  margin-bottom: 15px;
}