.silk-cleardb {
  max-width: 520px;
  margin: 2rem auto;
  padding: 0 1.5rem 3rem;
}

/* ── Header ── */
.silk-cleardb__header {
  display: flex;
  align-items: center;
  gap: 10px;
  margin-bottom: 0.4rem;
}

.silk-cleardb__icon {
  width: 22px;
  height: 22px;
  color: var(--silk-perf-bad);
  flex-shrink: 0;
}

.silk-cleardb__title {
  font-size: 1.25rem;
  font-weight: normal;
  color: var(--silk-text-primary);
  margin: 0;
}

.silk-cleardb__desc {
  font-size: 13px;
  color: var(--silk-text-secondary);
  margin: 0 0 1.5rem;
  font-weight: normal;
}

/* ── Options ── */
.silk-cleardb__options {
  display: flex;
  flex-direction: column;
  gap: 8px;
  margin-bottom: 1.5rem;
}

.silk-cleardb__option {
  display: flex;
  align-items: center;
  gap: 12px;
  padding: 12px 16px;
  border: 1px solid var(--silk-border);
  border-radius: var(--silk-card-radius, 8px);
  background: var(--silk-surface);
  cursor: pointer;
  font-weight: normal;
  transition: border-color 0.15s, background 0.15s;

  input[type="checkbox"] {
    width: 16px;
    height: 16px;
    accent-color: var(--silk-perf-bad);
    flex-shrink: 0;
    cursor: pointer;
  }

  &--disabled {
    opacity: 0.4;
    cursor: not-allowed;

    input[type="checkbox"] { cursor: not-allowed; }
  }

  &:not(&--disabled):hover {
    border-color: var(--silk-perf-bad);
    background: var(--silk-row-hover-bg);
  }

  &:has(input:checked) {
    border-color: var(--silk-perf-bad);
    background: var(--silk-filter-bg);
  }
}

.silk-cleardb__option-body {
  display: flex;
  align-items: center;
  gap: 10px;
  font-size: 14px;
  color: var(--silk-text-primary);

  .silk-icon {
    width: 16px;
    height: 16px;
    color: var(--silk-text-secondary);
    flex-shrink: 0;
  }
}

.silk-cleardb__option-name {
  font-size: 13px;
  color: var(--silk-text-primary);
  font-weight: normal;
}

.silk-cleardb__option-hint {
  font-size: 11px;
  color: var(--silk-text-muted);
  margin-top: 1px;
  font-weight: lighter;
}

/* ── Submit button ── */
.silk-cleardb__btn {
  font-family: FiraSans, "Helvetica Neue", Arial, sans-serif;
  font-size: 13px;
  font-weight: normal;
  padding: 8px 18px;
  border-radius: 6px;
  border: none;
  cursor: pointer;
  display: inline-flex;
  align-items: center;
  gap: 6px;
  background: var(--silk-perf-bad);
  color: #fff;
  transition: opacity 0.15s;

  .silk-icon { width: 14px; height: 14px; }

  &:hover:not(:disabled) { opacity: 0.85; }

  &:disabled {
    opacity: 0.35;
    cursor: not-allowed;
  }
}

/* ── Success message ── */
.silk-cleardb__msg {
  display: flex;
  align-items: center;
  gap: 8px;
  margin-top: 1.25rem;
  padding: 10px 14px;
  border-radius: 6px;
  background: var(--silk-filter-bg);
  border: 1px solid var(--silk-border);
  font-size: 13px;
  color: var(--silk-perf-good);
  font-style: italic;

  .silk-icon {
    width: 15px;
    height: 15px;
    flex-shrink: 0;
  }
}
