.very-good-font-color {
  color: var(--silk-perf-very-good);
}

.good-font-color {
  color: var(--silk-perf-good);
}

.ok-font-color {
  color: var(--silk-perf-ok);
}

.bad-font-color {
  color: var(--silk-perf-bad);
}

.very-bad-font-color {
  color: var(--silk-perf-very-bad);
}