{% load silk_nav %}
<div class="menu-item selectable-menu-item {% navactive request 'silk:summary' %}">
    <a href="{% url "silk:summary" %}">
        <div class="menu-item-outer">
            <div class="menu-item-inner">
                <i data-lucide="activity" class="silk-icon"></i> Summary
            </div>
        </div>
    </a>
</div>
<div class="menu-item selectable-menu-item {% navactive request 'silk:requests' %}">
    <a href="{% url "silk:requests" %}">
        <div class="menu-item-outer">
            <div class="menu-item-inner">
                <i data-lucide="layers" class="silk-icon"></i> Requests
            </div>
        </div>
    </a>
</div>
<div class="menu-item selectable-menu-item {% navactive request 'silk:profiling' %}">
    <a href="{% url "silk:profiling" %}">
        <div class="menu-item-outer">
            <div class="menu-item-inner">
                <i data-lucide="cpu" class="silk-icon"></i> Profiling
            </div>
        </div>
    </a>
</div>
<div class="menu-item selectable-menu-item {% navactive request 'silk:cleardb' %}">
    <a href="{% url "silk:cleardb" %}">
        <div class="menu-item-outer">
            <div class="menu-item-inner">
                <i data-lucide="trash-2" class="silk-icon"></i> Clear DB
            </div>
        </div>
    </a>
</div>
